# Governance

## The Organization

The mission of the Lexicon Community is to create an effective, active blueprint for collective ownership of Lexicons in the ATMosphere and build a stable and thoughtful lexicon that can be used by application, system, and SDK developers.

It does so through a partnership between Technical Steering Committee, Collaborators, and the broad AT Protocol community to work on a shared Lexicon and provide infrastructure to support it.

The [lexicon-community/governance](https://github.com/lexicon-community/governance) project contains a list of contributors.

## Technical Steering Committee

This project is collectively governed by a Technical Steering Committee (TSC) that has final authority over this project, including:

* Technical direction
* Lexicon additions and changes
* Project governance and process
* Collaborator and contribution governance
* Project infrastructure

Initial membership in the TSC was granted to individuals who have been active contributors to ATProtocol applications, libraries, and components. Membership will evolve and adapt to meet the project's needs.

See the [Consent Seeking Decision Process](#consent-seeking-decision-process) below for further details on the consensus model used for governance.

## Collaborators

Collaborators are individuals who contribute to the Lexicon Community. They may represent themselves or an organization.

Collaborators' primary responsibility is contributing to the technical and non-technical discussions and proposals within the Lexicon Community. There is no requirement that collaborators are AT Protocol software developers.

## Working Groups

The work of the Lexicon Community starts with working groups. Working groups are groups of individuals selected by the technical steering committee to collaborate for a specific purpose.

Additions and significant changes to the Lexicon Community schema, infrastructure, and organization start with the designation of a working group with a vote of formation by the technical steering committee. Only TSC members may propose working groups, so non-TSC members must seek sponsorship.

There are two requirements for forming a working group:

1. An objective that is documented and used by the working group to focus the scope of its work.
2. A vote by technical steering committee members.

A working group's objective and the produced result do not need to be a finished product, and it is not expected that the produced result will be used as is.

For example, the technical steering committee could form a working group with three volunteers to "Provide an initial lexicon schema with documentation and reference code for recipe data structures and present a recommendation to the TSC in 30 days."

The TSC is ultimately responsible for ensuring working groups deliver on their objectives, taking further action, or disbanding working groups, and does so at its discretion.

## Consent Seeking Decision Process

Lexicon Community follows a consent-seeking decision-making model, on the model of [Sociocratic organizations](https://www.sociocracyforall.org/consent-decision-making/) and the [IETF](https://datatracker.ietf.org/doc/html/rfc7282).

After a discussion of an agenda item, the moderator goes around each voting party and asks, "Do you have any objection to the proposal?". If a valid objection is raised, the proposal cannot move forward as is, and must be amended until no objections are left. Amendments might include adding trial periods, reducing the scope of the proposal, or further research.

A decision is made when there is no objection left.

### Valid Objections

In consent-seeking decision-making, valid objections cannot be a matter of personal preference, but must represent a potential harm to the group’s purpose or strategy. By raising an objection, a person signals that the current proposal is outside their range of tolerance, and poses a risk they believe the group cannot afford to take.

By not raising an objection, each participant agrees the proposal is: 

* "Good enough for now," moving the Lexicon Community towards its stated objectives.
* "Safe enough to try," not causing irreparable or disproportionate harm to the Lexicon Community’s mission.

### Overriding Objections 

Since each objection is a signal that someone thinks irreparable harm might come to the group’s goals, it is paramount that the group listens to objections and deeply tries to understand the reasoning behind them, even when they might not seem to make sense at first.

Overriding an objection should be a last resort, and might by itself harm the goals of the group in the long term. Should it become necessary, an objection can be overridden by majority vote.

## Announcements and News

The Technical Steering Committee communicates official news and announcements in two ways:

1. Through "Announcement" categorized discussions in the [lexicon-community/governance](https://github.com/lexicon-community/governance) and [lexicon-community/lexicon](https://github.com/lexicon-community/lexicon) GitHub discussions

2. Through social media posts on the official [@lexicon.community](https://hopper.at/?aturi=at%3A%2F%2Flexicon.community) account.

## General Discourse

The Technical Steering Committee and collaborators encourage and moderate collaboration with the intention of producing tangible contributions to the Lexicon Community.

Discourse takes several forms, but official channels include:

* GitHub Discussions, Issues, and Pull-Requests
* Discord
* Email

Any comments, opinions, or writings of technical steering committee members and collaborators are their own and not of Lexicon Community unless explicitly indicated within the writing at the time.

## Contributor Guide and Covenant

The Lexicon Community organization does not limit contributions to technical steering committee members and collaborators, but there are guidelines that everyone must follow.

See [Contributor Guide](CONTRIBUTING.md) and [Contributor Covenant](COVENANT.md).

Community members who refuse to adhere to the Contributor Guide or Contributor Covenant may be expelled from the project.
